/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2018 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp18nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp18nid ;

DATA library.&dataset ;
INFILE datafile LRECL=2557;
INPUT
   SENTRNGE  1              ACCEPT  2-3              BUSCLAS  4-7          
   CANTPAY  8               CCULPSCO  9              CH2APP  10            
   CH8FINGD  11             CMSRVORD  12             COFI  13              
   COMPLY  14-15            COMPLYPR  16             CRIMPURP  17          
   DETBFINE  18             DISPOSIT  19             EMPLOYNM  20          
   FCULPSCO  21             FRAUDTYP  22-23          FINSTDS  24           
   HISTORY  25              HSMISCND  26             INCORLOC  27          
   INCORPYR  28-31          INDICT  32               INPLEA1  33           
   INPLEA2  34              INPLEA3  35              INPLEA4  36           
   INPLEA5  37              INPLEA6  38              INPLEA7  39           
   INPLEA8  40              INPLEA9  41              INPLEA10  42          
   INPLEA11  43             INPLEA12  44             INNOPL1  45           
   INNOPL2  46              INNOPL3  47              INNOPL4  48           
   INNOPL5  49              INNOPL6  50              INNOPL7  51           
   INNOPL8  52              INNOPL9  53              INNOPL10  54          
   INNOPL11  55             INNOPL12  56             JANDC  57             
   NEWCNVTN  58             NOCOMP  59               NOCOUNTS  60-61       
   NOREAVAR  62             NOUSTAT  63              OBSTRUCT  64          
   OFFLVL  65-66            ORDERCE  67              ORGTYPE  68           
   OWNSTRCT  69             PLEA  70                 PRIMOFF  71-72        
   PRCIVIL  73              PRCRIME  74              PROBATN  75-76        
   PROBMON  77              PSR  78                  QUARTER  79           
   REAS1  80-83             REAS2  84-86             REASON3  87           
   REASON4  88              REASONS  89              REMEDORD  90          
   SELFREP  91              SOURCES  92              TOLERNCE  93          
   TYPEOTHS  94-95          VICTNOTE  96             VIOLATE  97           
   AMENDYR  98-101          SENTYR  102-105          BASEFINE  106-115     
   COSTASSM  116            DISGORGE  117-122        FINOFFST  123         
   FORFEITR  124-131        GLFINMAX  132-141        GLFINMIN  142-151     
   STATMIN  152             STATMAX  153-161         RESTCAT  162          
   FINECAT  163             SUSFNCAT  164            LCAT1  165            
   LCAT2  166               LCATHI  167              LCATS1  168           
   LCATS2  169              LCATSHI  170             LCATR1  171           
   LCATR2  172              LCATRHI  173             LCATC1  174           
   LCATC2  175              LCATCHI  176             LCATU1  177           
   LCATU2  178              LCATUHI  179             CPIDN  180-186        
   BUSTEXT $ 187-259        FINSTXT $ 260-324        OWNSTEXT $ 325        
   PRMONTXT $ 326-402       ORDERTXT $ 403-579       TYPEOTTX $ 580-828    
   MINFINML  829-832        MAXFINML  833-835        ADJOFL1  836-837      
   ADJOFL2  838-839         ADJOFLHI  840-841        ADJ_B1  842-843       
   ADJ_B2  844              ADJ_BHI  845-846         ADJ_C1  847-848       
   ADJ_C2  849              ADJ_CHI  850-851         ADJ_D1  852-853       
   ADJ_D2  854              ADJ_DHI  855-856         ADJ_E1  857           
   ADJ_E2  858              ADJ_EHI  859             ADJ_F1  860           
   ADJ_F2  861              ADJ_FHI  862             ADJ_G1  863           
   ADJ_G2  864              ADJ_GHI  865             ADJ_H1  866           
   ADJ_H2  867              ADJ_HHI  868             ADJ_I1  869           
   ADJ_I2  870              ADJ_IHI  871             ADJ_J1  872           
   ADJ_J2  873              ADJ_JHI  874             ADJ_K1  875           
   ADJ_K2  876              ADJ_KHI  877             ADJ_L1  878           
   ADJ_L2  879              ADJ_LHI  880             ADJ_M1  881           
   ADJ_M2  882              ADJ_MHI  883             ADJ_N1  884           
   ADJ_N2  885              ADJ_NHI  886             ADJ_O1  887           
   ADJ_O2  888              ADJ_OHI  889             ADJ_P1  890           
   ADJ_P2  891              ADJ_PHI  892             ADJ_Q1  893           
   ADJ_Q2  894              ADJ_QHI  895             ADJ_R1  896           
   ADJ_R2  897              ADJ_RHI  898             ADJ_S1  899           
   ADJ_S2  900              ADJ_SHI  901             ADJ_T1  902           
   ADJ_T2  903              ADJ_THI  904             BASADJ1  905          
   BASADJ2  906             BASADJHI  907            BASE1  908-909        
   BASE2  910-911           BASEHI  912-913          BASLN1  914           
   BASLN2  915              BASLNHI  916             ADJOFS1  917-918      
   ADJOFS2  919-920         ADJOFSHI  921-922        ADJS_B1  923-924      
   ADJS_B2  925             ADJS_BHI  926-927        ADJS_C1  928-929      
   ADJS_C2  930             ADJS_CHI  931-932        ADJS_D1  933-934      
   ADJS_D2  935             ADJS_DHI  936-937        ADJS_E1  938          
   ADJS_E2  939             ADJS_EHI  940            ADJS_F1  941          
   ADJS_F2  942             ADJS_FHI  943            ADJS_G1  944          
   ADJS_G2  945             ADJS_GHI  946            ADJS_H1  947          
   ADJS_H2  948             ADJS_HHI  949            ADJS_I1  950          
   ADJS_I2  951             ADJS_IHI  952            ADJS_J1  953          
   ADJS_J2  954             ADJS_JHI  955            ADJS_K1  956          
   ADJS_K2  957             ADJS_KHI  958            ADJS_L1  959          
   ADJS_L2  960             ADJS_LHI  961            ADJS_M1  962          
   ADJS_M2  963             ADJS_MHI  964            ADJS_N1  965          
   ADJS_N2  966             ADJS_NHI  967            ADJS_O1  968          
   ADJS_O2  969             ADJS_OHI  970            ADJS_P1  971          
   ADJS_P2  972             ADJS_PHI  973            ADJS_Q1  974          
   ADJS_Q2  975             ADJS_QHI  976            ADJS_R1  977          
   ADJS_R2  978             ADJS_RHI  979            ADJS_S1  980          
   ADJS_S2  981             ADJS_SHI  982            ADJS_T1  983          
   ADJS_T2  984             ADJS_THI  985            BASADS1  986          
   BASADS2  987             BASADSHI  988            BASES1  989-990       
   BASES2  991-992          BASESHI  993-994         BASLNS1  995          
   BASLNS2  996             BASLNSHI  997            ADJOFR1  998-999      
   ADJOFR2  1000            ADJOFRHI  1001-1002      ADJR_B1  1003-1004    
   ADJR_B2  1005            ADJR_BHI  1006-1007      ADJR_C1  1008         
   ADJR_C2  1009            ADJR_CHI  1010           ADJR_D1  1011         
   ADJR_D2  1012            ADJR_DHI  1013           ADJR_E1  1014         
   ADJR_E2  1015            ADJR_EHI  1016           ADJR_F1  1017         
   ADJR_F2  1018            ADJR_FHI  1019           ADJR_G1  1020         
   ADJR_G2  1021            ADJR_GHI  1022           ADJR_H1  1023         
   ADJR_H2  1024            ADJR_HHI  1025           ADJR_I1  1026         
   ADJR_I2  1027            ADJR_IHI  1028           ADJR_J1  1029         
   ADJR_J2  1030            ADJR_JHI  1031           ADJR_K1  1032         
   ADJR_K2  1033            ADJR_KHI  1034           ADJR_L1  1035         
   ADJR_L2  1036            ADJR_LHI  1037           ADJR_M1  1038         
   ADJR_M2  1039            ADJR_MHI  1040           ADJR_N1  1041         
   ADJR_N2  1042            ADJR_NHI  1043           ADJR_O1  1044         
   ADJR_O2  1045            ADJR_OHI  1046           ADJR_P1  1047         
   ADJR_P2  1048            ADJR_PHI  1049           ADJR_Q1  1050         
   ADJR_Q2  1051            ADJR_QHI  1052           ADJR_R1  1053         
   ADJR_R2  1054            ADJR_RHI  1055           ADJR_S1  1056         
   ADJR_S2  1057            ADJR_SHI  1058           ADJR_T1  1059         
   ADJR_T2  1060            ADJR_THI  1061           BASADR1  1062         
   BASADR2  1063            BASADRHI  1064           BASER1  1065-1066     
   BASER2  1067             BASERHI  1068-1069       BASLNR1  1070         
   BASLNR2  1071            BASLNRHI  1072           ADJOFC1  1073-1074    
   ADJOFC2  1075            ADJOFCHI  1076-1077      ADJC_B1  1078-1079    
   ADJC_B2  1080            ADJC_BHI  1081-1082      ADJC_C1  1083         
   ADJC_C2  1084            ADJC_CHI  1085           ADJC_D1  1086         
   ADJC_D2  1087            ADJC_DHI  1088           ADJC_E1  1089         
   ADJC_E2  1090            ADJC_EHI  1091           ADJC_F1  1092         
   ADJC_F2  1093            ADJC_FHI  1094           ADJC_G1  1095         
   ADJC_G2  1096            ADJC_GHI  1097           ADJC_H1  1098         
   ADJC_H2  1099            ADJC_HHI  1100           ADJC_I1  1101         
   ADJC_I2  1102            ADJC_IHI  1103           ADJC_J1  1104         
   ADJC_J2  1105            ADJC_JHI  1106           ADJC_K1  1107         
   ADJC_K2  1108            ADJC_KHI  1109           ADJC_L1  1110         
   ADJC_L2  1111            ADJC_LHI  1112           ADJC_M1  1113         
   ADJC_M2  1114            ADJC_MHI  1115           ADJC_N1  1116         
   ADJC_N2  1117            ADJC_NHI  1118           ADJC_O1  1119         
   ADJC_O2  1120            ADJC_OHI  1121           ADJC_P1  1122         
   ADJC_P2  1123            ADJC_PHI  1124           ADJC_Q1  1125         
   ADJC_Q2  1126            ADJC_QHI  1127           ADJC_R1  1128         
   ADJC_R2  1129            ADJC_RHI  1130           ADJC_S1  1131         
   ADJC_S2  1132            ADJC_SHI  1133           ADJC_T1  1134         
   ADJC_T2  1135            ADJC_THI  1136           BASADC1  1137         
   BASADC2  1138            BASADCHI  1139           BASEC1  1140-1141     
   BASEC2  1142             BASECHI  1143-1144       BASLNC1  1145         
   BASLNC2  1146            BASLNCHI  1147           ADJOFU1  1148         
   ADJOFU2  1149            ADJOFUHI  1150           ADJU_B1  1151         
   ADJU_B2  1152            ADJU_BHI  1153           ADJU_C1  1154         
   ADJU_C2  1155            ADJU_CHI  1156           ADJU_D1  1157         
   ADJU_D2  1158            ADJU_DHI  1159           ADJU_E1  1160         
   ADJU_E2  1161            ADJU_EHI  1162           ADJU_F1  1163         
   ADJU_F2  1164            ADJU_FHI  1165           ADJU_G1  1166         
   ADJU_G2  1167            ADJU_GHI  1168           ADJU_H1  1169         
   ADJU_H2  1170            ADJU_HHI  1171           ADJU_I1  1172         
   ADJU_I2  1173            ADJU_IHI  1174           ADJU_J1  1175         
   ADJU_J2  1176            ADJU_JHI  1177           ADJU_K1  1178         
   ADJU_K2  1179            ADJU_KHI  1180           ADJU_L1  1181         
   ADJU_L2  1182            ADJU_LHI  1183           ADJU_M1  1184         
   ADJU_M2  1185            ADJU_MHI  1186           ADJU_N1  1187         
   ADJU_N2  1188            ADJU_NHI  1189           ADJU_O1  1190         
   ADJU_O2  1191            ADJU_OHI  1192           ADJU_P1  1193         
   ADJU_P2  1194            ADJU_PHI  1195           ADJU_Q1  1196         
   ADJU_Q2  1197            ADJU_QHI  1198           ADJU_R1  1199         
   ADJU_R2  1200            ADJU_RHI  1201           ADJU_S1  1202         
   ADJU_S2  1203            ADJU_SHI  1204           ADJU_T1  1205         
   ADJU_T2  1206            ADJU_THI  1207           BASADU1  1208         
   BASADU2  1209            BASADUHI  1210           BASEU1  1211          
   BASEU2  1212             BASEUHI  1213            BASLNU1  1214         
   BASLNU2  1215            BASLNUHI  1216           ADJL_B1 $ 1217        
   ADJL_B2 $ 1218           ADJL_BHI $ 1219          ADJL_C1 $ 1220-1221   
   ADJL_C2 $ 1222           ADJL_CHI $ 1223-1224     ADJL_D1 $ 1225        
   ADJL_D2 $ 1226           ADJL_DHI $ 1227          ADJL_E1 $ 1228        
   ADJL_E2 $ 1229           ADJL_EHI $ 1230          ADJL_F1 $ 1231        
   ADJL_F2 $ 1232           ADJL_FHI $ 1233          ADJL_G1 $ 1234        
   ADJL_G2 $ 1235           ADJL_GHI $ 1236          ADJL_H1 $ 1237        
   ADJL_H2 $ 1238           ADJL_HHI $ 1239          ADJL_I1 $ 1240        
   ADJL_I2 $ 1241           ADJL_IHI $ 1242          ADJL_J1 $ 1243        
   ADJL_J2 $ 1244           ADJL_JHI $ 1245          ADJL_K1 $ 1246        
   ADJL_K2 $ 1247           ADJL_KHI $ 1248          ADJL_L1 $ 1249        
   ADJL_L2 $ 1250           ADJL_LHI $ 1251          ADJL_M1 $ 1252        
   ADJL_M2 $ 1253           ADJL_MHI $ 1254          ADJL_N1 $ 1255        
   ADJL_N2 $ 1256           ADJL_NHI $ 1257          ADJL_O1 $ 1258-1259   
   ADJL_O2 $ 1260           ADJL_OHI $ 1261-1262     ADJL_P1 $ 1263        
   ADJL_P2 $ 1264           ADJL_PHI $ 1265          ADJL_Q1 $ 1266        
   ADJL_Q2 $ 1267           ADJL_QHI $ 1268          ADJL_R1 $ 1269        
   ADJL_R2 $ 1270           ADJL_RHI $ 1271          ADJL_S1 $ 1272        
   ADJL_S2 $ 1273           ADJL_SHI $ 1274          ADJL_T1 $ 1275-1276   
   ADJL_T2 $ 1277           ADJL_THI $ 1278-1279     BASEL1 $ 1280         
   BASEL2 $ 1281            BASELHI $ 1282           ADSL_B1 $ 1283        
   ADSL_B2 $ 1284           ADSL_BHI $ 1285          ADSL_C1 $ 1286-1287   
   ADSL_C2 $ 1288           ADSL_CHI $ 1289-1290     ADSL_D1 $ 1291        
   ADSL_D2 $ 1292           ADSL_DHI $ 1293          ADSL_E1 $ 1294        
   ADSL_E2 $ 1295           ADSL_EHI $ 1296          ADSL_F1 $ 1297        
   ADSL_F2 $ 1298           ADSL_FHI $ 1299          ADSL_G1 $ 1300        
   ADSL_G2 $ 1301           ADSL_GHI $ 1302          ADSL_H1 $ 1303        
   ADSL_H2 $ 1304           ADSL_HHI $ 1305          ADSL_I1 $ 1306        
   ADSL_I2 $ 1307           ADSL_IHI $ 1308          ADSL_J1 $ 1309        
   ADSL_J2 $ 1310           ADSL_JHI $ 1311          ADSL_K1 $ 1312        
   ADSL_K2 $ 1313           ADSL_KHI $ 1314          ADSL_L1 $ 1315        
   ADSL_L2 $ 1316           ADSL_LHI $ 1317          ADSL_M1 $ 1318        
   ADSL_M2 $ 1319           ADSL_MHI $ 1320          ADSL_N1 $ 1321        
   ADSL_N2 $ 1322           ADSL_NHI $ 1323          ADSL_O1 $ 1324-1325   
   ADSL_O2 $ 1326           ADSL_OHI $ 1327-1328     ADSL_P1 $ 1329        
   ADSL_P2 $ 1330           ADSL_PHI $ 1331          ADSL_Q1 $ 1332        
   ADSL_Q2 $ 1333           ADSL_QHI $ 1334          ADSL_R1 $ 1335        
   ADSL_R2 $ 1336           ADSL_RHI $ 1337          ADSL_S1 $ 1338        
   ADSL_S2 $ 1339           ADSL_SHI $ 1340          ADSL_T1 $ 1341-1342   
   ADSL_T2 $ 1343           ADSL_THI $ 1344-1345     BASESL1 $ 1346        
   BASESL2 $ 1347           BASESLHI $ 1348          ADRL_B1 $ 1349        
   ADRL_B2 $ 1350           ADRL_BHI $ 1351          ADRL_C1 $ 1352-1353   
   ADRL_C2 $ 1354           ADRL_CHI $ 1355-1356     ADRL_D1 $ 1357        
   ADRL_D2 $ 1358           ADRL_DHI $ 1359          ADRL_E1 $ 1360        
   ADRL_E2 $ 1361           ADRL_EHI $ 1362          ADRL_F1 $ 1363        
   ADRL_F2 $ 1364           ADRL_FHI $ 1365          ADRL_G1 $ 1366        
   ADRL_G2 $ 1367           ADRL_GHI $ 1368          ADRL_H1 $ 1369        
   ADRL_H2 $ 1370           ADRL_HHI $ 1371          ADRL_I1 $ 1372        
   ADRL_I2 $ 1373           ADRL_IHI $ 1374          ADRL_J1 $ 1375        
   ADRL_J2 $ 1376           ADRL_JHI $ 1377          ADRL_K1 $ 1378        
   ADRL_K2 $ 1379           ADRL_KHI $ 1380          ADRL_L1 $ 1381        
   ADRL_L2 $ 1382           ADRL_LHI $ 1383          ADRL_M1 $ 1384        
   ADRL_M2 $ 1385           ADRL_MHI $ 1386          ADRL_N1 $ 1387        
   ADRL_N2 $ 1388           ADRL_NHI $ 1389          ADRL_O1 $ 1390        
   ADRL_O2 $ 1391           ADRL_OHI $ 1392          ADRL_P1 $ 1393        
   ADRL_P2 $ 1394           ADRL_PHI $ 1395          ADRL_Q1 $ 1396        
   ADRL_Q2 $ 1397           ADRL_QHI $ 1398          ADRL_R1 $ 1399        
   ADRL_R2 $ 1400           ADRL_RHI $ 1401          ADRL_S1 $ 1402        
   ADRL_S2 $ 1403           ADRL_SHI $ 1404          ADRL_T1 $ 1405        
   ADRL_T2 $ 1406           ADRL_THI $ 1407          BASERL1 $ 1408        
   BASERL2 $ 1409           BASERLHI $ 1410          ADCL_B1 $ 1411        
   ADCL_B2 $ 1412           ADCL_BHI $ 1413          ADCL_C1 $ 1414        
   ADCL_C2 $ 1415           ADCL_CHI $ 1416          ADCL_D1 $ 1417        
   ADCL_D2 $ 1418           ADCL_DHI $ 1419          ADCL_E1 $ 1420        
   ADCL_E2 $ 1421           ADCL_EHI $ 1422          ADCL_F1 $ 1423        
   ADCL_F2 $ 1424           ADCL_FHI $ 1425          ADCL_G1 $ 1426        
   ADCL_G2 $ 1427           ADCL_GHI $ 1428          ADCL_H1 $ 1429        
   ADCL_H2 $ 1430           ADCL_HHI $ 1431          ADCL_I1 $ 1432        
   ADCL_I2 $ 1433           ADCL_IHI $ 1434          ADCL_J1 $ 1435        
   ADCL_J2 $ 1436           ADCL_JHI $ 1437          ADCL_K1 $ 1438        
   ADCL_K2 $ 1439           ADCL_KHI $ 1440          ADCL_L1 $ 1441        
   ADCL_L2 $ 1442           ADCL_LHI $ 1443          ADCL_M1 $ 1444        
   ADCL_M2 $ 1445           ADCL_MHI $ 1446          ADCL_N1 $ 1447        
   ADCL_N2 $ 1448           ADCL_NHI $ 1449          ADCL_O1 $ 1450        
   ADCL_O2 $ 1451           ADCL_OHI $ 1452          ADCL_P1 $ 1453        
   ADCL_P2 $ 1454           ADCL_PHI $ 1455          ADCL_Q1 $ 1456        
   ADCL_Q2 $ 1457           ADCL_QHI $ 1458          ADCL_R1 $ 1459        
   ADCL_R2 $ 1460           ADCL_RHI $ 1461          ADCL_S1 $ 1462        
   ADCL_S2 $ 1463           ADCL_SHI $ 1464          ADCL_T1 $ 1465        
   ADCL_T2 $ 1466           ADCL_THI $ 1467          BASECL1 $ 1468        
   BASECL2 $ 1469           BASECLHI $ 1470          ADUL_B1 $ 1471        
   ADUL_B2 $ 1472           ADUL_BHI $ 1473          ADUL_C1 $ 1474        
   ADUL_C2 $ 1475           ADUL_CHI $ 1476          ADUL_D1 $ 1477        
   ADUL_D2 $ 1478           ADUL_DHI $ 1479          ADUL_E1 $ 1480        
   ADUL_E2 $ 1481           ADUL_EHI $ 1482          ADUL_F1 $ 1483        
   ADUL_F2 $ 1484           ADUL_FHI $ 1485          ADUL_G1 $ 1486        
   ADUL_G2 $ 1487           ADUL_GHI $ 1488          ADUL_H1 $ 1489        
   ADUL_H2 $ 1490           ADUL_HHI $ 1491          ADUL_I1 $ 1492        
   ADUL_I2 $ 1493           ADUL_IHI $ 1494          ADUL_J1 $ 1495        
   ADUL_J2 $ 1496           ADUL_JHI $ 1497          ADUL_K1 $ 1498        
   ADUL_K2 $ 1499           ADUL_KHI $ 1500          ADUL_L1 $ 1501        
   ADUL_L2 $ 1502           ADUL_LHI $ 1503          ADUL_M1 $ 1504        
   ADUL_M2 $ 1505           ADUL_MHI $ 1506          ADUL_N1 $ 1507        
   ADUL_N2 $ 1508           ADUL_NHI $ 1509          ADUL_O1 $ 1510        
   ADUL_O2 $ 1511           ADUL_OHI $ 1512          ADUL_P1 $ 1513        
   ADUL_P2 $ 1514           ADUL_PHI $ 1515          ADUL_Q1 $ 1516        
   ADUL_Q2 $ 1517           ADUL_QHI $ 1518          ADUL_R1 $ 1519        
   ADUL_R2 $ 1520           ADUL_RHI $ 1521          ADUL_S1 $ 1522        
   ADUL_S2 $ 1523           ADUL_SHI $ 1524          ADUL_T1 $ 1525        
   ADUL_T2 $ 1526           ADUL_THI $ 1527          BASEUL1 $ 1528        
   BASEUL2 $ 1529           BASEULHI $ 1530          GDLINE1 $ 1531-1535   
   GDLINE2 $ 1536-1540      GDSTAT1 $ 1541-1545      GDSTAT2 $ 1546-1550   
   GDREF1 $ 1551-1555       GDREF2 $ 1556-1560       GDCROS1 $ 1561-1565   
   GDCROS2 $ 1566           GDUNDR1 $ 1567           GDUNDR2 $ 1568        
   GDLINEHI $ 1569-1573     GDSTATHI $ 1574-1578     GDREFHI $ 1579-1583   
   GDCROSHI $ 1584-1588     GDUNDRHI $ 1589          STA1_1 $ 1590-1599    
   STA1_2 $ 1600-1608       STA1_3 $ 1609-1616       STA1_4 $ 1617-1624    
   STA1_5 $ 1625-1630       STA1_6 $ 1631-1636       STA1_7 $ 1637-1642    
   STA1_8 $ 1643-1648       STA1_9 $ 1649-1654       STA1_10 $ 1655-1660   
   STA1_11 $ 1661-1666      STA1_12 $ 1667-1672      STA1_13 $ 1673-1678   
   STA1_14 $ 1679-1684      STA1_15 $ 1685-1690      STA1_16 $ 1691-1696   
   STA1_17 $ 1697-1702      STA1_18 $ 1703-1708      STA1_19 $ 1709-1714   
   STA1_20 $ 1715-1720      STA1_21 $ 1721-1726      STA1_22 $ 1727-1732   
   STA1_23 $ 1733-1738      STA1_24 $ 1739-1744      STA1_25 $ 1745-1750   
   STA1_26 $ 1751-1756      STA1_27 $ 1757-1762      STA1_28 $ 1763-1768   
   STA1_29 $ 1769-1774      STA1_30 $ 1775-1780      STA1_31 $ 1781-1786   
   STA1_32 $ 1787-1794      STA1_33 $ 1795-1802      STA1_34 $ 1803-1810   
   STA1_35 $ 1811-1818      STA1_36 $ 1819-1826      STA1_37 $ 1827-1834   
   STA1_38 $ 1835-1842      STA1_39 $ 1843-1850      STA2_1 $ 1851-1859    
   STA2_2 $ 1860-1867       STA2_3 $ 1868-1875       STA2_4 $ 1876-1881    
   STA2_5 $ 1882-1887       STA2_6 $ 1888-1893       STA2_7 $ 1894-1899    
   STA2_8 $ 1900-1905       STA2_9 $ 1906-1911       STA2_10 $ 1912-1917   
   STA2_11 $ 1918-1923      STA2_12 $ 1924-1929      STA2_13 $ 1930-1935   
   STA2_14 $ 1936-1941      STA2_15 $ 1942-1947      STA2_16 $ 1948-1953   
   STA2_17 $ 1954-1959      STA2_18 $ 1960-1965      STA2_19 $ 1966-1971   
   STA2_20 $ 1972-1977      STA2_21 $ 1978-1980      STA2_22 $ 1981-1983   
   STA2_23 $ 1984-1986      STA2_24 $ 1987-1989      STA2_25 $ 1990-1992   
   STA2_26 $ 1993-1995      STA2_27 $ 1996-1998      STA2_28 $ 1999-2001   
   STA2_29 $ 2002-2004      STA2_30 $ 2005-2007      STA2_31 $ 2008-2010   
   STA2_32 $ 2011-2013      STA2_33 $ 2014-2016      STA2_34 $ 2017-2024   
   STA2_35 $ 2025-2032      STA2_36 $ 2033-2040      STA2_37 $ 2041-2048   
   STA2_38 $ 2049-2056      STA2_39 $ 2057-2064      STA3_1 $ 2065-2072    
   STA3_2 $ 2073-2082       STA3_3 $ 2083-2085       STA3_4 $ 2086-2088    
   STA3_5 $ 2089-2091       STA3_6 $ 2092-2094       STA3_7 $ 2095-2097    
   STA3_8 $ 2098-2100       STA3_9 $ 2101-2103       STA3_10 $ 2104-2106   
   STA3_11 $ 2107-2109      STA3_12 $ 2110-2112      STA3_13 $ 2113-2115   
   STA3_14 $ 2116-2118      STA3_15 $ 2119-2121      STA3_16 $ 2122-2124   
   STA3_17 $ 2125-2127      STA3_18 $ 2128-2130      STA3_19 $ 2131-2133   
   STA3_20 $ 2134-2136      STA3_21 $ 2137           STA3_22 $ 2138        
   STA3_23 $ 2139           STA3_24 $ 2140           STA3_25 $ 2141        
   STA3_26 $ 2142           STA3_27 $ 2143           STA3_28 $ 2144        
   STA3_29 $ 2145           STA3_30 $ 2146           STA3_31 $ 2147        
   STA3_32 $ 2148           STA3_33 $ 2149           STA3_34 $ 2150-2152   
   STA3_35 $ 2153-2155      STA3_36 $ 2156-2158      STA3_37 $ 2159-2161   
   STA3_38 $ 2162-2164      STA3_39 $ 2165-2167      NWSTAT1 $ 2168-2177   
   NWSTAT2 $ 2178-2186      NWSTAT3 $ 2187-2194      NWSTAT4 $ 2195-2202   
   NWSTAT5 $ 2203-2210      NWSTAT6 $ 2211-2218      NWSTAT7 $ 2219-2228   
   NWSTAT8 $ 2229-2236      SMAX1  2237-2245         SMAX2  2246-2253      
   SMAX3  2254-2259         SMAX4  2260-2265         SMAX5  2266-2271      
   SMAX6  2272-2277         SMAX7  2278-2283         SMAX8  2284-2289      
   SMAX9  2290-2295         SMAX10  2296-2301        SMAX11  2302-2307     
   SMAX12  2308-2313        SMAX13  2314-2319        SMAX14  2320-2325     
   SMAX15  2326-2331        SMAX16  2332-2337        SMAX17  2338-2343     
   SMAX18  2344-2349        SMAX19  2350-2355        SMAX20  2356-2361     
   SMAX21  2362-2367        SMAX22  2368-2373        SMAX23  2374-2379     
   SMAX24  2380-2385        SMAX25  2386-2391        SMAX26  2392-2397     
   SMAX27  2398-2403        SMAX28  2404-2409        SMAX29  2410-2415     
   SMAX30  2416-2421        SMAX31  2422-2427        SMAX32  2428-2433     
   SMAX33  2434-2439        SMAX34  2440-2445        SMAX35  2446-2451     
   SMAX36  2452-2457        SMAX37  2458-2463        SMAX38  2464-2469     
   SMAX39  2470-2475        SMIN1  2476              SMIN2  2477           
   SMIN3  2478              SMIN4  2479              SMIN5  2480           
   SMIN6  2481              SMIN7  2482              SMIN8  2483           
   SMIN9  2484              SMIN10  2485             SMIN11  2486          
   SMIN12  2487             SMIN13  2488             SMIN14  2489          
   SMIN15  2490             SMIN16  2491             SMIN17  2492          
   SMIN18  2493             SMIN19  2494             SMIN20  2495          
   SMIN21  2496             SMIN22  2497             SMIN23  2498          
   SMIN24  2499             SMIN25  2500             SMIN26  2501          
   SMIN27  2502             SMIN28  2503             SMIN29  2504          
   SMIN30  2505             SMIN31  2506             SMIN32  2507          
   SMIN33  2508             SMIN34  2509             SMIN35  2510          
   SMIN36  2511             SMIN37  2512             SMIN38  2513          
   SMIN39  2514             RETEXT1 $ 2515-2556      RETEXT2 $ 2557        
 ;                       

LENGTH
   SENTRNGE 3               ACCEPT 3                 BUSCLAS 4             
   CANTPAY 3                CCULPSCO 3               CH2APP 3              
   CH8FINGD 3               CMSRVORD 3               COFI 3                
   COMPLY 3                 COMPLYPR 3               CRIMPURP 3            
   DETBFINE 3               DISPOSIT 3               EMPLOYNM 3            
   FCULPSCO 3               FRAUDTYP 3               FINSTDS 3             
   HISTORY 3                HSMISCND 3               INCORLOC 3            
   INCORPYR 4               INDICT 3                 INPLEA1 3             
   INPLEA2 3                INPLEA3 3                INPLEA4 3             
   INPLEA5 3                INPLEA6 3                INPLEA7 3             
   INPLEA8 3                INPLEA9 3                INPLEA10 3            
   INPLEA11 3               INPLEA12 3               INNOPL1 3             
   INNOPL2 3                INNOPL3 3                INNOPL4 3             
   INNOPL5 3                INNOPL6 3                INNOPL7 3             
   INNOPL8 3                INNOPL9 3                INNOPL10 3            
   INNOPL11 3               INNOPL12 3               JANDC 3               
   NEWCNVTN 3               NOCOMP 3                 NOCOUNTS 3            
   NOREAVAR 3               NOUSTAT 3                OBSTRUCT 3            
   OFFLVL 3                 ORDERCE 3                ORGTYPE 3             
   OWNSTRCT 3               PLEA 3                   PRIMOFF 3             
   PRCIVIL 3                PRCRIME 3                PROBATN 3             
   PROBMON 3                PSR 3                    QUARTER 3             
   REAS1 4                  REAS2 4                  REASON3 3             
   REASON4 3                REASONS 3                REMEDORD 3            
   SELFREP 3                SOURCES 3                TOLERNCE 3            
   TYPEOTHS 3               VICTNOTE 3               VIOLATE 3             
   AMENDYR 4                SENTYR 4                 COSTASSM 3            
   DISGORGE 6               FINOFFST 3               FORFEITR 6            
   STATMIN 3                STATMAX 6                RESTCAT 3             
   FINECAT 3                SUSFNCAT 3               LCAT1 3               
   LCAT2 3                  LCATHI 3                 LCATS1 3              
   LCATS2 3                 LCATSHI 3                LCATR1 3              
   LCATR2 3                 LCATRHI 3                LCATC1 3              
   LCATC2 3                 LCATCHI 3                LCATU1 3              
   LCATU2 3                 LCATUHI 3                CPIDN 6               
   ADJOFL1 3                ADJOFL2 3                ADJOFLHI 3            
   ADJ_B1 3                 ADJ_B2 3                 ADJ_BHI 3             
   ADJ_C1 3                 ADJ_C2 3                 ADJ_CHI 3             
   ADJ_D1 3                 ADJ_D2 3                 ADJ_DHI 3             
   ADJ_E1 3                 ADJ_E2 3                 ADJ_EHI 3             
   ADJ_F1 3                 ADJ_F2 3                 ADJ_FHI 3             
   ADJ_G1 3                 ADJ_G2 3                 ADJ_GHI 3             
   ADJ_H1 3                 ADJ_H2 3                 ADJ_HHI 3             
   ADJ_I1 3                 ADJ_I2 3                 ADJ_IHI 3             
   ADJ_J1 3                 ADJ_J2 3                 ADJ_JHI 3             
   ADJ_K1 3                 ADJ_K2 3                 ADJ_KHI 3             
   ADJ_L1 3                 ADJ_L2 3                 ADJ_LHI 3             
   ADJ_M1 3                 ADJ_M2 3                 ADJ_MHI 3             
   ADJ_N1 3                 ADJ_N2 3                 ADJ_NHI 3             
   ADJ_O1 3                 ADJ_O2 3                 ADJ_OHI 3             
   ADJ_P1 3                 ADJ_P2 3                 ADJ_PHI 3             
   ADJ_Q1 3                 ADJ_Q2 3                 ADJ_QHI 3             
   ADJ_R1 3                 ADJ_R2 3                 ADJ_RHI 3             
   ADJ_S1 3                 ADJ_S2 3                 ADJ_SHI 3             
   ADJ_T1 3                 ADJ_T2 3                 ADJ_THI 3             
   BASADJ1 3                BASADJ2 3                BASADJHI 3            
   BASE1 3                  BASE2 3                  BASEHI 3              
   BASLN1 3                 BASLN2 3                 BASLNHI 3             
   ADJOFS1 3                ADJOFS2 3                ADJOFSHI 3            
   ADJS_B1 3                ADJS_B2 3                ADJS_BHI 3            
   ADJS_C1 3                ADJS_C2 3                ADJS_CHI 3            
   ADJS_D1 3                ADJS_D2 3                ADJS_DHI 3            
   ADJS_E1 3                ADJS_E2 3                ADJS_EHI 3            
   ADJS_F1 3                ADJS_F2 3                ADJS_FHI 3            
   ADJS_G1 3                ADJS_G2 3                ADJS_GHI 3            
   ADJS_H1 3                ADJS_H2 3                ADJS_HHI 3            
   ADJS_I1 3                ADJS_I2 3                ADJS_IHI 3            
   ADJS_J1 3                ADJS_J2 3                ADJS_JHI 3            
   ADJS_K1 3                ADJS_K2 3                ADJS_KHI 3            
   ADJS_L1 3                ADJS_L2 3                ADJS_LHI 3            
   ADJS_M1 3                ADJS_M2 3                ADJS_MHI 3            
   ADJS_N1 3                ADJS_N2 3                ADJS_NHI 3            
   ADJS_O1 3                ADJS_O2 3                ADJS_OHI 3            
   ADJS_P1 3                ADJS_P2 3                ADJS_PHI 3            
   ADJS_Q1 3                ADJS_Q2 3                ADJS_QHI 3            
   ADJS_R1 3                ADJS_R2 3                ADJS_RHI 3            
   ADJS_S1 3                ADJS_S2 3                ADJS_SHI 3            
   ADJS_T1 3                ADJS_T2 3                ADJS_THI 3            
   BASADS1 3                BASADS2 3                BASADSHI 3            
   BASES1 3                 BASES2 3                 BASESHI 3             
   BASLNS1 3                BASLNS2 3                BASLNSHI 3            
   ADJOFR1 3                ADJOFR2 3                ADJOFRHI 3            
   ADJR_B1 3                ADJR_B2 3                ADJR_BHI 3            
   ADJR_C1 3                ADJR_C2 3                ADJR_CHI 3            
   ADJR_D1 3                ADJR_D2 3                ADJR_DHI 3            
   ADJR_E1 3                ADJR_E2 3                ADJR_EHI 3            
   ADJR_F1 3                ADJR_F2 3                ADJR_FHI 3            
   ADJR_G1 3                ADJR_G2 3                ADJR_GHI 3            
   ADJR_H1 3                ADJR_H2 3                ADJR_HHI 3            
   ADJR_I1 3                ADJR_I2 3                ADJR_IHI 3            
   ADJR_J1 3                ADJR_J2 3                ADJR_JHI 3            
   ADJR_K1 3                ADJR_K2 3                ADJR_KHI 3            
   ADJR_L1 3                ADJR_L2 3                ADJR_LHI 3            
   ADJR_M1 3                ADJR_M2 3                ADJR_MHI 3            
   ADJR_N1 3                ADJR_N2 3                ADJR_NHI 3            
   ADJR_O1 3                ADJR_O2 3                ADJR_OHI 3            
   ADJR_P1 3                ADJR_P2 3                ADJR_PHI 3            
   ADJR_Q1 3                ADJR_Q2 3                ADJR_QHI 3            
   ADJR_R1 3                ADJR_R2 3                ADJR_RHI 3            
   ADJR_S1 3                ADJR_S2 3                ADJR_SHI 3            
   ADJR_T1 3                ADJR_T2 3                ADJR_THI 3            
   BASADR1 3                BASADR2 3                BASADRHI 3            
   BASER1 3                 BASER2 3                 BASERHI 3             
   BASLNR1 3                BASLNR2 3                BASLNRHI 3            
   ADJOFC1 3                ADJOFC2 3                ADJOFCHI 3            
   ADJC_B1 3                ADJC_B2 3                ADJC_BHI 3            
   ADJC_C1 3                ADJC_C2 3                ADJC_CHI 3            
   ADJC_D1 3                ADJC_D2 3                ADJC_DHI 3            
   ADJC_E1 3                ADJC_E2 3                ADJC_EHI 3            
   ADJC_F1 3                ADJC_F2 3                ADJC_FHI 3            
   ADJC_G1 3                ADJC_G2 3                ADJC_GHI 3            
   ADJC_H1 3                ADJC_H2 3                ADJC_HHI 3            
   ADJC_I1 3                ADJC_I2 3                ADJC_IHI 3            
   ADJC_J1 3                ADJC_J2 3                ADJC_JHI 3            
   ADJC_K1 3                ADJC_K2 3                ADJC_KHI 3            
   ADJC_L1 3                ADJC_L2 3                ADJC_LHI 3            
   ADJC_M1 3                ADJC_M2 3                ADJC_MHI 3            
   ADJC_N1 3                ADJC_N2 3                ADJC_NHI 3            
   ADJC_O1 3                ADJC_O2 3                ADJC_OHI 3            
   ADJC_P1 3                ADJC_P2 3                ADJC_PHI 3            
   ADJC_Q1 3                ADJC_Q2 3                ADJC_QHI 3            
   ADJC_R1 3                ADJC_R2 3                ADJC_RHI 3            
   ADJC_S1 3                ADJC_S2 3                ADJC_SHI 3            
   ADJC_T1 3                ADJC_T2 3                ADJC_THI 3            
   BASADC1 3                BASADC2 3                BASADCHI 3            
   BASEC1 3                 BASEC2 3                 BASECHI 3             
   BASLNC1 3                BASLNC2 3                BASLNCHI 3            
   ADJOFU1 3                ADJOFU2 3                ADJOFUHI 3            
   ADJU_B1 3                ADJU_B2 3                ADJU_BHI 3            
   ADJU_C1 3                ADJU_C2 3                ADJU_CHI 3            
   ADJU_D1 3                ADJU_D2 3                ADJU_DHI 3            
   ADJU_E1 3                ADJU_E2 3                ADJU_EHI 3            
   ADJU_F1 3                ADJU_F2 3                ADJU_FHI 3            
   ADJU_G1 3                ADJU_G2 3                ADJU_GHI 3            
   ADJU_H1 3                ADJU_H2 3                ADJU_HHI 3            
   ADJU_I1 3                ADJU_I2 3                ADJU_IHI 3            
   ADJU_J1 3                ADJU_J2 3                ADJU_JHI 3            
   ADJU_K1 3                ADJU_K2 3                ADJU_KHI 3            
   ADJU_L1 3                ADJU_L2 3                ADJU_LHI 3            
   ADJU_M1 3                ADJU_M2 3                ADJU_MHI 3            
   ADJU_N1 3                ADJU_N2 3                ADJU_NHI 3            
   ADJU_O1 3                ADJU_O2 3                ADJU_OHI 3            
   ADJU_P1 3                ADJU_P2 3                ADJU_PHI 3            
   ADJU_Q1 3                ADJU_Q2 3                ADJU_QHI 3            
   ADJU_R1 3                ADJU_R2 3                ADJU_RHI 3            
   ADJU_S1 3                ADJU_S2 3                ADJU_SHI 3            
   ADJU_T1 3                ADJU_T2 3                ADJU_THI 3            
   BASADU1 3                BASADU2 3                BASADUHI 3            
   BASEU1 3                 BASEU2 3                 BASEUHI 3             
   BASLNU1 3                BASLNU2 3                BASLNUHI 3            
   SMAX1 6                  SMAX2 6                  SMAX3 6               
   SMAX4 6                  SMAX5 6                  SMAX6 6               
   SMAX7 6                  SMAX8 6                  SMAX9 6               
   SMAX10 6                 SMAX11 6                 SMAX12 6              
   SMAX13 6                 SMAX14 6                 SMAX15 6              
   SMAX16 6                 SMAX17 6                 SMAX18 6              
   SMAX19 6                 SMAX20 6                 SMAX21 6              
   SMAX22 6                 SMAX23 6                 SMAX24 6              
   SMAX25 6                 SMAX26 6                 SMAX27 6              
   SMAX28 6                 SMAX29 6                 SMAX30 6              
   SMAX31 6                 SMAX32 6                 SMAX33 6              
   SMAX34 6                 SMAX35 6                 SMAX36 6              
   SMAX37 6                 SMAX38 6                 SMAX39 6              
   SMIN1 3                  SMIN2 3                  SMIN3 3               
   SMIN4 3                  SMIN5 3                  SMIN6 3               
   SMIN7 3                  SMIN8 3                  SMIN9 3               
   SMIN10 3                 SMIN11 3                 SMIN12 3              
   SMIN13 3                 SMIN14 3                 SMIN15 3              
   SMIN16 3                 SMIN17 3                 SMIN18 3              
   SMIN19 3                 SMIN20 3                 SMIN21 3              
   SMIN22 3                 SMIN23 3                 SMIN24 3              
   SMIN25 3                 SMIN26 3                 SMIN27 3              
   SMIN28 3                 SMIN29 3                 SMIN30 3              
   SMIN31 3                 SMIN32 3                 SMIN33 3              
   SMIN34 3                 SMIN35 3                 SMIN36 3              
   SMIN37 3                 SMIN38 3                 SMIN39 3 ;

          

RUN ;
